@@ -102,7 +102,7 @@ static inline ssize_t redir_write(int fd, const void *buf, size_t size, int in)
 		rand_time = rand() % (random_wait * 2);
 		syslog(LOG_DEBUG, "random wait: %u", rand_time);
 		waitbw.tv_sec  = rand_time / 1000;
-		waitbw.tv_usec = rand_time % 1000;
+		waitbw.tv_usec = (rand_time % 1000) * 1000;
 
 		select(1, &empty, NULL, NULL, &waitbw);
 	}
@@ -120,7 +120,7 @@ static inline ssize_t redir_write(int fd, const void *buf, size_t size, int in)
 		bits = size * 8;
 		syslog(LOG_DEBUG, "bandwidth wait: %lu", 1000 * bits / max_bandwidth);
 		waitbw.tv_sec  = bits / max_bandwidth;
-		waitbw.tv_usec = (1000 * (bits % max_bandwidth)) / max_bandwidth;
+		waitbw.tv_usec = (1000000 * (bits % max_bandwidth)) / max_bandwidth;
 
 		select(1, &empty, NULL, NULL, &waitbw);
 	}
@@ -134,19 +134,19 @@ static inline ssize_t redir_write(int fd, const void *buf, size_t size, int in)
 
 static int usage(int code)
 {
-	fprintf(stderr,"\n"
+	fprintf(stdout,"\n"
 		"Usage: %s [-hinspv] [-b IP]  [-f TYPE] [-I NAME] [-l LEVEL] [-t SEC]\n"
 		"                       [-x STR] [-m BPS] [-o FLAG] [-w MSEC] [-z BYTES]\n"
 		"                       [SRC]:PORT [DST]:PORT\n", prognm);
-	fprintf(stderr, "\n"
+	fprintf(stdout, "\n"
 		"Options:\n"
 		" -b, --bind=IP            Force specific IP to bind() to when listening for\n"
 		"                          incoming connections.  Not applicable with -p\n"
-		" -h, --help               Show this help text\n"
 #ifndef NO_FTP
 		" -f, --ftp=TYPE           Redirect FTP connections.  Where type is\n"
 		"                          one of: 'port', 'pasv', or 'both'\n"
 #endif
+		" -h, --help               Show this help text\n"
 		" -i, --inetd              Run from inetd, SRC:PORT comes from stdin\n"
 		"                          Usage: %s [OPTIONS] [DST]:PORT\n"
 		" -I, --ident=NAME         Identity, tag syslog messages with NAME\n"
@@ -365,7 +365,7 @@ static void parse_args(int argc, char *argv[])
 			break;
  #endif
 		case 'v':
-			fprintf(stderr, "%s\n", PACKAGE_VERSION);
+			fprintf(stdout, "%s\n", PACKAGE_VERSION);
 			exit(0);
 
 		case 'x':
